==> lyx_1.6.5.orig.tar.gz: lyx-1.6.5/src/lyxcore.cpp <==

#include "Author.cpp" 
#include "Bidi.cpp" 
#include "boost.cpp" 
#include "BranchList.cpp" 
#include "Buffer.cpp" 
#include "buffer_funcs.cpp" 
#include "BufferList.cpp" 
#include "BufferParams.cpp" 
#include "BufferView.cpp" 
#include "Bullet.cpp" 
#include "Changes.cpp" 
#include "Chktex.cpp" 
#include "CmdDef.cpp" 
#include "Color.cpp" 
#include "ConverterCache.cpp" 
#include "Converter.cpp" 
#include "CoordCache.cpp" 
#include "Counters.cpp" 
#include "Cursor.cpp" 
#include "CursorSlice.cpp" 
#include "CutAndPaste.cpp" 
#include "DepTable.cpp" 
#include "DocIterator.cpp" 
#include "Encoding.cpp" 
#include "ErrorList.cpp" 
#include "Exporter.cpp" 
#include "factory.cpp" 
#include "Floating.cpp" 
#include "FloatList.cpp" 
#include "FontInfo.cpp" 
#include "FontList.cpp" 
#include "Font.cpp" 
#include "Format.cpp" 
#include "FuncRequest.cpp" 
#include "FuncStatus.cpp" 
#include "Graph.cpp" 
#include "InsetIterator.cpp" 
#include "InsetList.cpp" 
#include "Intl.cpp" 
#include "KeyMap.cpp" 
#include "KeySequence.cpp" 
#include "Language.cpp" 
#include "LaTeX.cpp" 
#include "LaTeXFeatures.cpp" 
#include "LayoutFile.cpp" 
#include "Length.cpp" 
#include "lengthcommon.cpp" 
#include "Lexer.cpp" 
#include "LyX.cpp" 
#include "LyXAction.cpp" 
#include "lyxfind.cpp" 
#include "LyXFunc.cpp" 
#include "LyXRC.cpp" 
#include "LyXVC.cpp" 
#include "MetricsInfo.cpp" 
#include "ModuleList.cpp" 
#include "Mover.cpp" 
#include "output_docbook.cpp" 
#include "output.cpp" 
#include "output_latex.cpp" 
#include "OutputParams.cpp" 
#include "output_plaintext.cpp" 
#include "Paragraph.cpp" 
#include "paragraph_funcs.cpp" 
#include "ParagraphMetrics.cpp" 
#include "ParagraphParameters.cpp" 
#include "ParIterator.cpp" 
#include "PDFOptions.cpp" 
#include "Row.cpp" 
#include "rowpainter.cpp" 
#include "Server.cpp" 
#include "ServerSocket.cpp" 
#include "sgml.cpp" 
#include "Session.cpp" 
#include "Spacing.cpp" 
#include "TexRow.cpp" 
#include "Text.cpp" 
#include "Text2.cpp" 
#include "Text3.cpp" 
#include "TexStream.cpp" 
#include "TextClass.cpp" 
#include "TextMetrics.cpp" 
#include "TocBackend.cpp" 
#include "Trans.cpp" 
#include "Undo.cpp" 
#include "VCBackend.cpp" 
#include "version.cpp" 
#include "VSpace.cpp" 
#include "WordList.cpp"

==> lyx_2.0.0.orig.tar.gz: lyx-2.0.0/src/lyxcore.cpp <==

#include "Author.cpp" 
#include "Bidi.cpp" 
#include "boost.cpp" 
#include "BranchList.cpp" 
#include "Buffer.cpp" 
#include "buffer_funcs.cpp" 
#include "BufferList.cpp" 
#include "BufferParams.cpp" 
#include "BufferView.cpp" 
#include "Bullet.cpp" 
#include "Changes.cpp" 
#include "Chktex.cpp" 
#include "CmdDef.cpp" 
#include "Color.cpp" 
#include "ConverterCache.cpp" 
#include "Converter.cpp" 
#include "CoordCache.cpp" 
#include "Counters.cpp" 
#include "Cursor.cpp" 
#include "CursorSlice.cpp" 
#include "CutAndPaste.cpp" 
#include "DepTable.cpp" 
#include "DocIterator.cpp" 
#include "Encoding.cpp" 
#include "ErrorList.cpp" 
#include "Exporter.cpp" 
#include "factory.cpp" 
#include "Floating.cpp" 
#include "FloatList.cpp" 
#include "FontInfo.cpp" 
#include "FontList.cpp" 
#include "Font.cpp" 
#include "Format.cpp" 
#include "FuncRequest.cpp" 
#include "FuncStatus.cpp" 
#include "Graph.cpp" 
#include "HSpace.cpp" 
#include "IndicesList.cpp" 
#include "InsetIterator.cpp" 
#include "InsetList.cpp" 
#include "Intl.cpp" 
#include "KeyMap.cpp" 
#include "KeySequence.cpp" 
#include "Language.cpp" 
#include "LaTeX.cpp" 
#include "LaTeXFeatures.cpp" 
#include "LayoutFile.cpp" 
#include "LayoutModuleList.cpp" 
#include "Length.cpp" 
#include "lengthcommon.cpp" 
#include "Lexer.cpp" 
#include "LyX.cpp" 
#include "LyXAction.cpp" 
#include "lyxfind.cpp" 
#include "LyXRC.cpp" 
#include "LyXVC.cpp" 
#include "MetricsInfo.cpp" 
#include "ModuleList.cpp" 
#include "Mover.cpp" 
#include "output_docbook.cpp" 
#include "output.cpp" 
#include "output_latex.cpp" 
#include "output_xhtml.cpp" 
#include "OutputParams.cpp" 
#include "output_plaintext.cpp" 
#include "Paragraph.cpp" 
#include "ParagraphMetrics.cpp" 
#include "ParagraphParameters.cpp" 
#include "ParIterator.cpp" 
#include "PDFOptions.cpp" 
#include "Row.cpp" 
#include "rowpainter.cpp" 
#include "Server.cpp" 
#include "ServerSocket.cpp" 
#include "sgml.cpp" 
#include "Session.cpp" 
#include "Spacing.cpp" 
#include "TexRow.cpp" 
#include "Text.cpp" 
#include "Text2.cpp" 
#include "Text3.cpp" 
#include "TexStream.cpp" 
#include "TextClass.cpp" 
#include "TextMetrics.cpp" 
#include "TocBackend.cpp" 
#include "Trans.cpp" 
#include "Undo.cpp" 
#include "VCBackend.cpp" 
#include "version.cpp" 
#include "VSpace.cpp" 
#include "WordList.cpp"
